Library containing Crazyflie 2.0 controller classes: - Attitude estimator - Horizontal estimator - Vertical estimator - Attitude controller - Horizontal controller - Vertical controller - Mixer

Revision:
18:60516a4cba27
Parent:
17:f682b4a5686d
Child:
19:83b357d6806e
--- a/VerticalEstimator/VerticalEstimator.h	Fri Oct 05 19:32:35 2018 +0000
+++ b/VerticalEstimator/VerticalEstimator.h	Wed Oct 10 10:48:52 2018 +0000
@@ -15,8 +15,8 @@
     void init();
     // Predict vertical position and velocity from model
     void predict();
-    // Update vertical position and velocity with measurement
-    void update(float phi, float theta);
+    // Correct vertical position and velocity with measurement
+    void correct(float phi, float theta);
     // Vertical position (m) and velocity (m/s) estimation
     float z, w;
   private: